@@ -60,6 +60,8 @@ from .constants import WARNING_DISCLAIMER_TEXT as WARNING_DISCLAIMER_TEXT
 from .constants import version as version
 from .context import Context as Context
 from .contextbuilder import ContextBuilder as ContextBuilder
+from .datetimes import datetime_from_chain as datetime_from_chain
+from .datetimes import datetime_from_timestamp as datetime_from_timestamp
 from .datetimes import local_now as local_now
 from .datetimes import utc_now as utc_now
 from .encoding import decode_binary as decode_binary
@@ -289,6 +291,7 @@ from .spotmarket import SpotMarketStub as SpotMarketStub
 from .text import indent_collection_as_str as indent_collection_as_str
 from .text import indent_item_by as indent_item_by
 from .tokens import Instrument as Instrument
+from .tokens import RoundDirection as RoundDirection
 from .tokens import SolToken as SolToken
 from .tokens import Token as Token
 from .tokenaccount import TokenAccount as TokenAccount
@@ -297,6 +300,9 @@ from .tokenbank import InterestRates as InterestRates
 from .tokenbank import NodeBank as NodeBank
 from .tokenbank import RootBank as RootBank
 from .tokenbank import TokenBank as TokenBank
+from .tokenoperations import (
+    build_create_associated_instructions_and_account as build_create_associated_instructions_and_account,
+)
 from .tradehistory import TradeHistory as TradeHistory
 from .transactionmonitoring import (
     SignatureSubscription as SignatureSubscription,
