@@ -36,7 +36,10 @@ from solana.keypair import Keypair
 from solana.publickey import PublicKey
 from solana.system_program import CreateAccountParams, create_account
 from solana.transaction import AccountMeta, TransactionInstruction
-from spl.token.constants import ACCOUNT_LEN, TOKEN_PROGRAM_ID
+from spl.token.constants import (
+    ACCOUNT_LEN,
+    TOKEN_PROGRAM_ID,
+)
 from spl.token.instructions import (
     CloseAccountParams,
     InitializeAccountParams,
@@ -249,10 +252,10 @@ def build_spl_create_account_instructions(
 # you specifically don't want the associated token account.
 #
 def build_spl_create_associated_account_instructions(
-    context: Context, wallet: Wallet, token: Token
+    context: Context, wallet: Wallet, owner: PublicKey, token: Token
 ) -> CombinableInstructions:
     create_account_instructions = create_associated_token_account(
-        wallet.address, wallet.address, token.mint
+        wallet.address, owner, token.mint
     )
     return CombinableInstructions(
         signers=[], instructions=[create_account_instructions]
@@ -271,7 +274,7 @@ def build_spl_transfer_tokens_instructions(
     destination: PublicKey,
     quantity: Decimal,
 ) -> CombinableInstructions:
-    amount = int(quantity * (10**token.decimals))
+    amount = int(token.shift_to_native(quantity))
     instructions = [
         transfer(
             TransferParams(
@@ -672,15 +675,9 @@ def build_spot_place_order_instructions(
     quantity: Decimal,
     client_id: int,
     fee_discount_address: PublicKey,
-    create_open_orders: bool,
 ) -> CombinableInstructions:
     instructions: CombinableInstructions = CombinableInstructions.empty()
 
-    if create_open_orders:
-        instructions += build_spot_create_openorders_instructions(
-            context, wallet, group, account, spot_market, open_orders_address
-        )
-
     pyserum_market: PySerumMarket = spot_market.underlying_serum_market
     serum_order_type: pyserum.enums.OrderType = order_type.to_serum()
     serum_side: pyserum.enums.Side = side.to_serum()
@@ -936,6 +933,104 @@ def build_perp_cancel_order_instructions(
     return CombinableInstructions(signers=[], instructions=instructions)
 
 
+# # 🥭 build_perp_cancel_all_orders_instructions function
+#
+# Builds the instructions necessary for cancelling all perp orders.
+#
+def build_perp_cancel_all_orders_instructions(
+    context: Context,
+    wallet: Wallet,
+    account: IAccount,
+    perp_market_details: PerpMarketDetails,
+    limit: Decimal = Decimal(32),
+) -> CombinableInstructions:
+    # Accounts expected by this instruction (seems to be the same as CANCEL_PERP_ORDER and CANCEL_PERP_ORDER_BY_CLIENT_ID):
+    # { isSigner: false, isWritable: false, pubkey: mangoGroupPk },
+    # { isSigner: false, isWritable: true, pubkey: mangoAccountPk },
+    # { isSigner: true, isWritable: false, pubkey: ownerPk },
+    # { isSigner: false, isWritable: true, pubkey: perpMarketPk },
+    # { isSigner: false, isWritable: true, pubkey: bidsPk },
+    # { isSigner: false, isWritable: true, pubkey: asksPk },
+    instructions = [
+        TransactionInstruction(
+            keys=[
+                AccountMeta(
+                    is_signer=False, is_writable=False, pubkey=account.group_address
+                ),
+                AccountMeta(is_signer=False, is_writable=True, pubkey=account.address),
+                AccountMeta(is_signer=True, is_writable=False, pubkey=wallet.address),
+                AccountMeta(
+                    is_signer=False,
+                    is_writable=True,
+                    pubkey=perp_market_details.address,
+                ),
+                AccountMeta(
+                    is_signer=False, is_writable=True, pubkey=perp_market_details.bids
+                ),
+                AccountMeta(
+                    is_signer=False, is_writable=True, pubkey=perp_market_details.asks
+                ),
+            ],
+            program_id=context.mango_program_address,
+            data=layouts.CANCEL_ALL_PERP_ORDERS.build({"limit": limit}),
+        )
+    ]
+    return CombinableInstructions(signers=[], instructions=instructions)
+
+
+# # 🥭 build_perp_cancel_all_side_instructions function
+#
+# Builds the instructions necessary for cancelling all perp orders on a given side.
+#
+def build_perp_cancel_all_side_instructions(
+    context: Context,
+    wallet: Wallet,
+    account: IAccount,
+    perp_market_details: PerpMarketDetails,
+    side: Side,
+    limit: Decimal = Decimal(32),
+) -> CombinableInstructions:
+    # { buy: 0, sell: 1 }
+    raw_side: int = 1 if side == Side.SELL else 0
+
+    # /// Cancel all perp open orders for one side of the book
+    # ///
+    # /// Accounts expected: 6
+    # /// 0. `[]` mango_group_ai - MangoGroup
+    # /// 1. `[writable]` mango_account_ai - MangoAccount
+    # /// 2. `[signer]` owner_ai - Owner of Mango Account
+    # /// 3. `[writable]` perp_market_ai - PerpMarket
+    # /// 4. `[writable]` bids_ai - Bids acc
+    # /// 5. `[writable]` asks_ai - Asks acc
+    instructions = [
+        TransactionInstruction(
+            keys=[
+                AccountMeta(
+                    is_signer=False, is_writable=False, pubkey=account.group_address
+                ),
+                AccountMeta(is_signer=False, is_writable=True, pubkey=account.address),
+                AccountMeta(is_signer=True, is_writable=False, pubkey=wallet.address),
+                AccountMeta(
+                    is_signer=False,
+                    is_writable=True,
+                    pubkey=perp_market_details.address,
+                ),
+                AccountMeta(
+                    is_signer=False, is_writable=True, pubkey=perp_market_details.bids
+                ),
+                AccountMeta(
+                    is_signer=False, is_writable=True, pubkey=perp_market_details.asks
+                ),
+            ],
+            program_id=context.mango_program_address,
+            data=layouts.CANCEL_PERP_ORDER_SIDE.build(
+                {"side": raw_side, "limit": limit}
+            ),
+        )
+    ]
+    return CombinableInstructions(signers=[], instructions=instructions)
+
+
 # /// Place an order on a perp market
 # ///
 # /// In case this order is matched, the corresponding order structs on both
@@ -1057,51 +1152,6 @@ def build_perp_place_order_instructions(
     return CombinableInstructions(signers=[], instructions=instructions)
 
 
-# # 🥭 build_perp_cancel_all_orders_instructions function
-#
-# Builds the instructions necessary for cancelling all perp orders.
-#
-def build_perp_cancel_all_orders_instructions(
-    context: Context,
-    wallet: Wallet,
-    account: IAccount,
-    perp_market_details: PerpMarketDetails,
-    limit: Decimal = Decimal(32),
-) -> CombinableInstructions:
-    # Accounts expected by this instruction (seems to be the same as CANCEL_PERP_ORDER and CANCEL_PERP_ORDER_BY_CLIENT_ID):
-    # { isSigner: false, isWritable: false, pubkey: mangoGroupPk },
-    # { isSigner: false, isWritable: true, pubkey: mangoAccountPk },
-    # { isSigner: true, isWritable: false, pubkey: ownerPk },
-    # { isSigner: false, isWritable: true, pubkey: perpMarketPk },
-    # { isSigner: false, isWritable: true, pubkey: bidsPk },
-    # { isSigner: false, isWritable: true, pubkey: asksPk },
-    instructions = [
-        TransactionInstruction(
-            keys=[
-                AccountMeta(
-                    is_signer=False, is_writable=False, pubkey=account.group_address
-                ),
-                AccountMeta(is_signer=False, is_writable=True, pubkey=account.address),
-                AccountMeta(is_signer=True, is_writable=False, pubkey=wallet.address),
-                AccountMeta(
-                    is_signer=False,
-                    is_writable=True,
-                    pubkey=perp_market_details.address,
-                ),
-                AccountMeta(
-                    is_signer=False, is_writable=True, pubkey=perp_market_details.bids
-                ),
-                AccountMeta(
-                    is_signer=False, is_writable=True, pubkey=perp_market_details.asks
-                ),
-            ],
-            program_id=context.mango_program_address,
-            data=layouts.CANCEL_ALL_PERP_ORDERS.build({"limit": limit}),
-        )
-    ]
-    return CombinableInstructions(signers=[], instructions=instructions)
-
-
 def build_perp_consume_events_instructions(
     context: Context,
     group: IGroup,
