@@ -33,12 +33,13 @@
 
 
 import construct
-import datetime
 import typing
 
+from datetime import datetime
 from decimal import Decimal, Context as DecimalContext
 from solana.publickey import PublicKey
 
+from ..datetimes import datetime_from_chain
 
 # # Adapters
 #
@@ -176,9 +177,7 @@ else:
 #
 if typing.TYPE_CHECKING:
 
-    class DatetimeAdapter(
-        construct.Adapter[datetime.datetime, int, typing.Any, typing.Any]
-    ):
+    class DatetimeAdapter(construct.Adapter[datetime, int, typing.Any, typing.Any]):
         def __init__(self) -> None:
             pass
 
@@ -188,14 +187,10 @@ else:
         def __init__(self) -> None:
             super().__init__(construct.BytesInteger(8, swapped=True))
 
-        def _decode(
-            self, obj: int, context: typing.Any, path: typing.Any
-        ) -> datetime.datetime:
-            return datetime.datetime.fromtimestamp(obj, tz=datetime.timezone.utc)
+        def _decode(self, obj: int, context: typing.Any, path: typing.Any) -> datetime:
+            return datetime_from_chain(obj)
 
-        def _encode(
-            self, obj: datetime.datetime, context: typing.Any, path: typing.Any
-        ) -> int:
+        def _encode(self, obj: datetime, context: typing.Any, path: typing.Any) -> int:
             return int(obj.timestamp())
 
 
@@ -1634,6 +1629,22 @@ CREATE_MANGO_ACCOUNT = construct.Struct(
 )
 
 
+# /// Cancel all perp open orders for one side of the book
+# ///
+# /// Accounts expected: 6
+# /// 0. `[]` mango_group_ai - MangoGroup
+# /// 1. `[writable]` mango_account_ai - MangoAccount
+# /// 2. `[signer]` owner_ai - Owner of Mango Account
+# /// 3. `[writable]` perp_market_ai - PerpMarket
+# /// 4. `[writable]` bids_ai - Bids acc
+# /// 5. `[writable]` asks_ai - Asks acc
+CANCEL_PERP_ORDER_SIDE = construct.Struct(
+    "variant" / construct.Const(57, construct.BytesInteger(4, swapped=True)),
+    "side" / DecimalAdapter(1),  # { buy: 0, sell: 1 }
+    "limit" / DecimalAdapter(1),
+)
+
+
 # /// https://github.com/blockworks-foundation/mango-v3/pull/97/
 # /// Set delegate authority to mango account which can do everything regular account can do
 # /// except Withdraw and CloseMangoAccount. Set to Pubkey::default() to revoke delegate
@@ -1797,7 +1808,7 @@ InstructionParsersByVariant = {
     54: UNSPECIFIED,  # RESOLVE_DUST,
     55: CREATE_MANGO_ACCOUNT,  # CREATE_MANGO_ACCOUNT,
     56: UNSPECIFIED,  # UPGRADE_MANGO_ACCOUNT_V0_V1,
-    57: UNSPECIFIED,  # CANCEL_PERP_ORDER_SIDE,
+    57: CANCEL_PERP_ORDER_SIDE,  # CANCEL_PERP_ORDER_SIDE,
     58: SET_DELEGATE,  # SET_DELEGATE,
     59: UNSPECIFIED,  # CHANGE_SPOT_MARKET_PARAMS,
     60: CREATE_SPOT_OPEN_ORDERS,  # CREATE_SPOT_OPEN_ORDERS,
