@@ -14,7 +14,6 @@
 #   [Email](mailto:hello@blockworks.foundation)
 
 
-import rx.operators
 import typing
 
 from dataclasses import dataclass
@@ -56,7 +55,6 @@ from .tokenbank import TokenBank
 from .wallet import Wallet
 from .websocketsubscription import (
     IndividualWebSocketSubscriptionManager,
-    WebSocketAccountSubscription,
 )
 
 
@@ -160,13 +158,19 @@ class PerpMarket(LoadedMarket):
     @staticmethod
     def ensure(market: Market) -> "PerpMarket":
         if not PerpMarket.isa(market):
-            raise Exception(f"Market for {market.symbol} is not a Perp market")
+            raise Exception(
+                f"Market for {market.fully_qualified_symbol} is not a Perp market"
+            )
         return typing.cast(PerpMarket, market)
 
     @property
     def symbol(self) -> str:
         return f"{self.base.symbol}-PERP"
 
+    @property
+    def fully_qualified_symbol(self) -> str:
+        return f"perp:{self.symbol}"
+
     @property
     def group(self) -> Group:
         return self.underlying_perp_market.group
@@ -225,26 +229,17 @@ class PerpMarket(LoadedMarket):
             context, self.event_queue_address, self.lot_size_converter
         )
 
-        splitter: UnseenPerpEventChangesTracker = UnseenPerpEventChangesTracker(initial)
-        event_queue_subscription = WebSocketAccountSubscription(
-            context,
-            self.event_queue_address,
-            lambda account_info: PerpEventQueue.parse(
-                account_info, self.lot_size_converter
-            ),
-        )
-        disposer.add_disposable(event_queue_subscription)
-
         manager = IndividualWebSocketSubscriptionManager(context)
         disposer.add_disposable(manager)
-        manager.add(event_queue_subscription)
 
-        publisher = event_queue_subscription.publisher.pipe(
-            rx.operators.flat_map(splitter.unseen)
-        )
+        splitter: UnseenPerpEventChangesTracker = UnseenPerpEventChangesTracker(initial)
 
-        individual_event_subscription = publisher.subscribe(on_next=handler)
-        disposer.add_disposable(individual_event_subscription)
+        def __split_handler(pev: PerpEventQueue) -> None:
+            for event in splitter.unseen(pev):
+                handler(event)
+
+        subscription = initial.subscribe(context, manager, __split_handler)
+        disposer.add_disposable(subscription)
 
         manager.open()
 
@@ -297,10 +292,6 @@ class PerpMarketInstructionBuilder(MarketInstructionBuilder):
     def build_cancel_order_instructions(
         self, order: Order, ok_if_missing: bool = False
     ) -> CombinableInstructions:
-        if self.perp_market.underlying_perp_market is None:
-            raise Exception(
-                f"PerpMarket {self.perp_market.symbol} has not been loaded."
-            )
         return build_perp_cancel_order_instructions(
             self.context,
             self.wallet,
@@ -311,10 +302,6 @@ class PerpMarketInstructionBuilder(MarketInstructionBuilder):
         )
 
     def build_place_order_instructions(self, order: Order) -> CombinableInstructions:
-        if self.perp_market.underlying_perp_market is None:
-            raise Exception(
-                f"PerpMarket {self.perp_market.symbol} has not been loaded."
-            )
         return build_perp_place_order_instructions(
             self.context,
             self.wallet,
@@ -338,11 +325,6 @@ class PerpMarketInstructionBuilder(MarketInstructionBuilder):
     def build_crank_instructions(
         self, addresses: typing.Sequence[PublicKey], limit: Decimal = Decimal(32)
     ) -> CombinableInstructions:
-        if self.perp_market.underlying_perp_market is None:
-            raise Exception(
-                f"PerpMarket {self.perp_market.symbol} has not been loaded."
-            )
-
         distinct_addresses: typing.List[PublicKey] = [self.account.address]
         for address in addresses:
             if address not in distinct_addresses:
@@ -382,10 +364,6 @@ class PerpMarketInstructionBuilder(MarketInstructionBuilder):
     def build_cancel_all_orders_instructions(
         self, limit: Decimal = Decimal(32)
     ) -> CombinableInstructions:
-        if self.perp_market.underlying_perp_market is None:
-            raise Exception(
-                f"PerpMarket {self.perp_market.symbol} has not been loaded."
-            )
         return build_perp_cancel_all_orders_instructions(
             self.context,
             self.wallet,
@@ -430,14 +408,10 @@ class PerpMarketOperations(MarketOperations):
     def perp_market(self) -> PerpMarket:
         return self.market_instruction_builder.perp_market
 
-    @property
-    def market_name(self) -> str:
-        return self.perp_market.symbol
-
     def cancel_order(
         self, order: Order, ok_if_missing: bool = False
     ) -> typing.Sequence[str]:
-        self._logger.info(f"Cancelling {self.market_name} order {order}.")
+        self._logger.info(f"Cancelling {self.symbol} order {order}.")
         signers: CombinableInstructions = CombinableInstructions.from_wallet(
             self.wallet
         )
@@ -458,7 +432,7 @@ class PerpMarketOperations(MarketOperations):
             self.wallet
         )
         order_with_client_id: Order = order.with_update(client_id=client_id)
-        self._logger.info(f"Placing {self.market_name} order {order_with_client_id}.")
+        self._logger.info(f"Placing {self.symbol} order {order_with_client_id}.")
         place: CombinableInstructions = (
             self.market_instruction_builder.build_place_order_instructions(
                 order_with_client_id
@@ -518,7 +492,7 @@ class PerpMarketOperations(MarketOperations):
         )
 
     def __str__(self) -> str:
-        return f"""« PerpMarketOperations [{self.market_name}] »"""
+        return f"""« PerpMarketOperations [{self.symbol}] »"""
 
 
 # # 🥭 PerpMarketStub class
@@ -545,6 +519,10 @@ class PerpMarketStub(Market):
         )
         self.group_address: PublicKey = group_address
 
+    @property
+    def fully_qualified_symbol(self) -> str:
+        return f"perp:{self.symbol}"
+
     def load(
         self, context: Context, group: typing.Optional[Group] = None
     ) -> PerpMarket:
