@@ -16,10 +16,16 @@
 import typing
 
 
-def indent_collection_as_str(collection: typing.Sequence[typing.Any]) -> str:
+def indent_collection_as_str(
+    collection: typing.Sequence[typing.Any], levels: int = 0
+) -> str:
+    spaces: int = levels * 4
+    spacing: str = " " * spaces
     if len(collection) == 0:
-        return "None"
-    return "\n    ".join(f"{item}" for item in collection)
+        return f"{spacing}None"
+    return f"{spacing}" + f"\n{spacing}".join(f"{item}" for item in collection).replace(
+        "\n", "\n    "
+    )
 
 
 def indent_item_by(item: typing.Any, levels: int = 1) -> str:
